macro_rules! here {
() => { ... };
}Expand description
Creates a “Location” type that displays the current location in code when printed.
macro_rules! here {
() => { ... };
}Creates a “Location” type that displays the current location in code when printed.