unwrap_here

Macro unwrap_here 

macro_rules! unwrap_here {
    ($description:expr, $operation:expr) => { ... };
}
Tries to resolve a result into a successful output (much like the ? operator). Unlike the ? operator, this macro adds context about the current line to the error message if something goes wrongw.